@@ -3,7 +3,7 @@ package Foorum::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '1.000006';
+our $VERSION = '1.000007';
 
 use base 'Exporter';
 use vars qw/@EXPORT_OK/;
@@ -14,6 +14,7 @@ use vars qw/@EXPORT_OK/;
     get_page_from_url
     truncate_text
     be_url_part
+    get_server_timezone_diff
     /;
 
 use Encode ();
@@ -96,6 +97,18 @@ sub be_url_part {
     return $str;
 }
 
+sub get_server_timezone_diff {
+    my @lmt  = (localtime);
+    my @gmt  = (gmtime);
+    my $diff = $gmt[2] - $lmt[2];
+    if ( $gmt[5] > $lmt[5] || $gmt[7] > $lmt[7] ) {
+        $diff += 24;
+    } elsif ( $gmt[5] < $lmt[5] || $gmt[7] < $lmt[7] ) {
+        $diff -= 24;
+    }
+    return $diff;
+}
+
 1;
 __END__
 
